# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

import os, json

def dict2json(sozluk:dict, liste_key:str, dosya_adi:str) -> bool:
    """
    dict2json({
        'kullanici_id'  : message.from_user.id,
        'kullanici_nick': f"@{message.from_user.username}" if message.from_user.username else None,
        'kullanici_adi' : f"{message.from_user.first_name or ''} {message.from_user.last_name or ''}".strip()
    }, liste_key="kullanici_id", dosya_adi=kullanicilar)
    """
    if os.path.isfile(dosya_adi):
        with open(dosya_adi, encoding='utf-8') as gelen_json:
            gelen_veri    = json.load(gelen_json)
            gelen_kisiler = [kisi[liste_key] for kisi in gelen_veri]

        if sozluk[liste_key] not in gelen_kisiler:
            gelen_veri.append(sozluk)
            gelen_essiz = [dict(sozluk) for sozluk in {tuple(liste_ici.items()) for liste_ici in gelen_veri}]
            gelen_a_z   = sorted(gelen_essiz, key=lambda sozluk: sozluk[liste_key])

            with open(dosya_adi, mode='w', encoding='utf-8') as dosya:
                dosya.write(json.dumps(gelen_a_z, indent=2, ensure_ascii=False, sort_keys=False))

            return True

        return False

    else:
        with open(dosya_adi, mode='w', encoding='utf-8') as dosya:
            liste = [sozluk]
            essiz = [dict(sozluk) for sozluk in {tuple(liste_ici.items()) for liste_ici in liste}]
            a_z   = sorted(essiz, key=lambda sozluk: sozluk[liste_key])

            dosya.write(json.dumps(a_z, indent=2, ensure_ascii=False, sort_keys=False))

            return True


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from typing               import Union
from smtplib              import SMTP
from email.mime.multipart import MIMEMultipart
from email.mime.text      import MIMEText

def mail_gonder(host:str, port:Union[int, str], mail:str, sifre:str, alici:str, konu:str, icerik:str, html:bool=False):
    mesaj = MIMEMultipart('alternative')
    mesaj['Subject'] = konu
    mesaj['From']    = mail
    mesaj['To']      = alici

    mesaj.attach(MIMEText(icerik, 'html') if html else MIMEText(icerik, 'plain'))

    smtp = SMTP(host, int(port))
    smtp.ehlo()
    smtp.starttls()
    smtp.login(mail, sifre)
    smtp.sendmail(mail, alici, mesaj.as_string())
    smtp.quit()


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from speech_recognition import Recognizer, Microphone
from gtts               import gTTS
from os                 import system, remove

def ses2yazi() -> str:
    dinleyici = Recognizer()
    with Microphone() as source:
        dinleyici.adjust_for_ambient_noise(source)
        veri = dinleyici.record(source, duration=5)
        yazi = dinleyici.recognize_google(veri, language="tr")
    return yazi

def yazi2ses(metin:str, mp3_adi:str) -> str:
    tts = gTTS(metin.strip(), lang="tr", slow=True)
    tts.save(f"{mp3_adi}.mp3")
    return f"{mp3_adi}.mp3"

def cevir(girdi_dosya:str, cikti_dosya:str) -> str:
    system(f'ffmpeg -hide_banner -loglevel error -y -i {girdi_dosya} -af "asetrate=44100*0.9, aresample=44100, atempo=1/0.9" {cikti_dosya}')
    remove(girdi_dosya)
    return cikti_dosya

def inceses(metin:str, cikti_adi:str) -> str:
    _gecici = yazi2ses(metin, "gecici")
    return cevir(_gecici, f"{cikti_adi}.mp3")

# print(inceses("Selam Kanka Naber bakalım?", "selam"))


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from setuptools import setup
from io         import open

setup(
    author       = "keyiflerolsun",
    author_email = "keyiflerolsun@gmail.com",

    packages     = ["Kekik"],

    name         = "Kekik",
    version      = "1.0.2",
    url          = "https://github.com/keyiflerolsun/Kekik",
    description  = 'İşlerimizi kolaylaştıracak fonksiyonların el altında durduğu kütüphane..',
    keywords     = ["Kekik", 'KekikAkademi', 'keyiflerolsun'],

    long_description_content_type = "text/markdown",
    long_description              = "".join(open("README.md", encoding="utf-8").readlines()),
    include_package_data          = True,

    license     = 'GPLv3+',
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 3'
    ],

    python_requires  = '>=3.8',
    install_requires = [
        "setuptools",
        "wheel",
        "pytz",
        "requests",
        "aiohttp",
        "thispersondoesnotexist",
        "simplejson",
        "rich",
        "tabulate",
        "tqdm",
        "qrcode",
        "pyfiglet",
        "Pillow",
        "notify-py"
    ]
)